@@ -25,7 +25,7 @@ NumericVector get_vals_lagcrit(List y, List x, int lag_crit, int h, int k, int m
                                  int n_obs){
 
   arma::mat xx, xx_one, yy, xpxi, emat, hhat;
-  arma::vec w1, beta, resids, resds_sq;
+  arma::vec w1, beta, resids, resids_sq;
   int rstart_y, rend_y, rend_x;
   double ssr, var_eps, ll, tp, n;
   double pi = 3.141593;
@@ -53,8 +53,8 @@ NumericVector get_vals_lagcrit(List y, List x, int lag_crit, int h, int k, int m
     xpxi     = inv(xx.t()*xx);
     beta     = xpxi*xx.t()*yy;
     resids   = yy - xx*beta;
-    resds_sq = resids%resids;
-    ssr      = sum(resds_sq);
+    resids_sq = resids%resids;
+    ssr      = sum(resids_sq);
     var_eps  = ssr/n;
 
     // Estimate log-likelihood
